@@ -1,7 +1,6 @@
 from typing import Callable, List, Optional, Dict, Any
 
-import numpy as np
-import numpy.typing as npt
+import numpy as np  # type: ignore
 
 from code_loader.contract.datasetclasses import SectionCallableInterface, InputHandler, \
     GroundTruthHandler, MetadataHandler, DatasetIntegrationSetup, DecoderHandler, PreprocessResponse, \
@@ -35,7 +34,7 @@ class DatasetBinder:
     def set_decoder(self, name: str,
                     decoder: DecoderCallableInterface,
                     type: LeapDataType,
-                    heatmap_decoder: Optional[Callable[[npt.NDArray[np.float32]], npt.NDArray[np.float32]]] = None) -> None:
+                    heatmap_decoder: Optional[Callable[[np.array], np.array]] = None) -> None:
         self.setup_container.decoders.append(DecoderHandler(name, decoder, type, heatmap_decoder))
         self._decoder_names.append(name)
 
